@@ -1,5 +1,3 @@
-use std::ops::Add;
-
 const LF: char = '\n';
 const HASH: char = '#';
 const B_SLASH: char = '\\';
@@ -21,9 +19,9 @@ pub enum Quote {
 
 /// To collect the info about the current line
 #[derive(Debug, PartialEq)]
-pub struct KeyVal {
+pub struct KeyVal<'k> {
     /// `key` of the variable
-    pub k: String,
+    pub k: &'k str,
 
     /// `value` of the variable
     pub v: String,
@@ -40,7 +38,7 @@ pub struct KeyVal {
 ///
 /// let line = Line::from("BASIC=basic");
 ///
-/// let k = "BASIC".to_string();
+/// let k = "BASIC";
 /// let v = "basic".to_string();
 /// assert_eq!(line, Line::KeyVal(KeyVal { k, v, q: Quote::No }));
 ///
@@ -52,20 +50,20 @@ pub struct KeyVal {
 /// // With quotes
 /// let quoted = Line::from("S_QUOTED='single_quoted'");
 ///
-/// let k = "S_QUOTED".to_string();
+/// let k = "S_QUOTED";
 /// let v = "single_quoted".to_string();
 /// assert_eq!(quoted, Line::KeyVal(KeyVal { k, v, q: Quote::Single }));
 /// ```
 #[derive(Debug, PartialEq)]
-pub enum Line {
+pub enum Line<'l> {
     /// When the current line is a `key=val` pair
-    KeyVal(KeyVal),
+    KeyVal(KeyVal<'l>),
 
     /// When the current line is empty
     Empty,
 }
 
-impl Line {
+impl<'l> Line<'l> {
     fn replace_lf(line: &str) -> String {
         let mut s = String::with_capacity(line.len());
         let mut chars = line.chars();
@@ -106,9 +104,9 @@ impl Line {
         }
     }
 
-    fn retain_quote(orgnl: String, after: String, q: Quote) -> (String, Quote) {
+    fn retain_quote(orgnl: &str, after: String, q: Quote) -> (String, Quote) {
         // If both strings length matches then it is not closed
-        if orgnl.len().eq(&after.len().add(1)) {
+        if orgnl.len().eq(&(after.len() + 1)) {
             let new_val: String = orgnl.chars().take_while(|c| c != &HASH).collect();
 
             (new_val.trim().to_string(), Quote::No)
@@ -118,8 +116,8 @@ impl Line {
     }
 }
 
-impl From<&str> for Line {
-    fn from(line: &str) -> Self {
+impl<'l> From<&'l str> for Line<'l> {
+    fn from(line: &'l str) -> Self {
         if line.is_empty() || line.starts_with(HASH) {
             return Self::Empty;
         };
@@ -128,7 +126,7 @@ impl From<&str> for Line {
 
         match (parts.next(), parts.next()) {
             (Some(k), Some(v)) => {
-                let key = k.trim().to_string();
+                let key = k.trim();
                 let mut chars = v.chars();
 
                 let first = chars.next();
@@ -140,7 +138,7 @@ impl From<&str> for Line {
                             Self::replace_lf(&v)
                         };
 
-                        let (v, q) = Self::retain_quote(v.to_string(), val, Quote::Double);
+                        let (v, q) = Self::retain_quote(v, val, Quote::Double);
 
                         Line::KeyVal(KeyVal { k: key, v, q })
                     }
@@ -150,7 +148,7 @@ impl From<&str> for Line {
                             .map(Self::escape_lf)
                             .collect();
 
-                        let (v, q) = Self::retain_quote(v.to_string(), val, Quote::Single);
+                        let (v, q) = Self::retain_quote(v, val, Quote::Single);
 
                         Line::KeyVal(KeyVal { k: key, v, q })
                     }
